@@ -2,6 +2,7 @@ import asyncio
 import platform
 from typing import Dict
 from collections import defaultdict
+import threading
 from nexustrader.constants import AccountType, ExchangeType
 from nexustrader.config import Config
 from nexustrader.strategy import Strategy
@@ -22,7 +23,6 @@ from nexustrader.exchange.bybit import (
     BybitPublicConnector,
     BybitAccountType,
     BybitExecutionManagementSystem,
-    BybitOrderManagementSystem,
 )
 from nexustrader.exchange.binance import (
     BinanceExchangeManager,
@@ -30,7 +30,6 @@ from nexustrader.exchange.binance import (
     BinancePublicConnector,
     BinancePrivateConnector,
     BinanceExecutionManagementSystem,
-    BinanceOrderManagementSystem,
 )
 from nexustrader.exchange.okx import (
     OkxExchangeManager,
@@ -38,10 +37,29 @@ from nexustrader.exchange.okx import (
     OkxPublicConnector,
     OkxPrivateConnector,
     OkxExecutionManagementSystem,
-    OkxOrderManagementSystem,
 )
+from nexustrader.exchange.hyperliquid import (
+    HyperLiquidExchangeManager,
+    HyperLiquidAccountType,
+    HyperLiquidPublicConnector,
+    HyperLiquidPrivateConnector,
+    HyperLiquidExecutionManagementSystem,
+)
+
+from nexustrader.exchange.bitget import (
+    BitgetExchangeManager,
+    BitgetPublicConnector,
+    BitgetPrivateConnector,
+    BitgetAccountType,
+    BitgetExecutionManagementSystem,
+)
+
 from nexustrader.core.entity import TaskManager, ZeroMQSignalRecv
-from nexustrader.core.nautilius_core import MessageBus, TraderId, LiveClock
+from nexustrader.core.nautilius_core import (
+    nautilus_pyo3,
+    Logger,
+    setup_nautilus_core,
+)
 from nexustrader.schema import InstrumentId
 from nexustrader.constants import DataType
 
@@ -61,6 +79,8 @@ class Engine:
         self.set_loop_policy()
         self._loop = asyncio.new_event_loop()
         self._task_manager = TaskManager(self._loop)
+        self._auto_flush_thread = None
+        self._auto_flush_stop_event = threading.Event()
 
         self._exchanges: Dict[ExchangeType, ExchangeManager] = {}
         self._public_connectors: Dict[AccountType, PublicConnector] = {}
@@ -70,15 +90,36 @@ class Engine:
 
         self._custom_signal_recv = None
 
-        self._msgbus = MessageBus(
-            trader_id=TraderId(trader_id),
-            clock=LiveClock(),
+        # Initialize logging with global reference
+        self._log_guard, self._msgbus, self._clock = setup_nautilus_core(
+            trader_id=trader_id,
+            level_stdout=self._config.log_config.level_stdout,
+            level_file=self._config.log_config.level_file,
+            directory=self._config.log_config.directory,
+            file_name=self._config.log_config.file_name,
+            file_format=self._config.log_config.file_format,
+            is_colored=self._config.log_config.colors,
+            print_config=self._config.log_config.print_config,
+            component_levels=self._config.log_config.component_levels,
+            file_rotate=(
+                (
+                    self._config.log_config.max_file_size,
+                    self._config.log_config.max_backup_count,
+                )
+                if self._config.log_config.max_file_size > 0
+                else None
+            ),
+            is_bypassed=self._config.log_config.bypass,
         )
 
+        # Create logger instance for Engine
+        self._log = Logger(type(self).__name__)
+
         self._cache: AsyncCache = AsyncCache(
             strategy_id=config.strategy_id,
             user_id=config.user_id,
             msgbus=self._msgbus,
+            clock=self._clock,
             task_manager=self._task_manager,
             storage_backend=config.storage_backend,
             db_path=config.db_path,
@@ -101,76 +142,40 @@ class Engine:
         self._strategy._init_core(
             cache=self._cache,
             msgbus=self._msgbus,
+            clock=self._clock,
             task_manager=self._task_manager,
             ems=self._ems,
             exchanges=self._exchanges,
             private_connectors=self._private_connectors,
             public_connectors=self._public_connectors,
+            strategy_id=config.strategy_id,
+            user_id=config.user_id,
+            enable_cli=config.enable_cli,
         )
 
     def _public_connector_check(self):
-        okx_public_conn_count = 0
+        # Group connectors by exchange
+        exchange_connectors = defaultdict(dict)
+        for account_type, connector in self._public_connectors.items():
+            exchange_id = ExchangeType(account_type.exchange_id.lower())
+            exchange_connectors[exchange_id][account_type] = connector
 
-        for account_type in self._public_connectors.keys():
-            if isinstance(account_type, BybitAccountType):
-                if (
-                    account_type == BybitAccountType.UNIFIED
-                    or account_type == BybitAccountType.UNIFIED_TESTNET
-                ):
-                    raise EngineBuildError(
-                        f"{account_type} is not supported for public connector."
-                    )
-                bybit_basic_config = self._config.basic_config.get(ExchangeType.BYBIT)
-                if not bybit_basic_config:
-                    raise EngineBuildError(
-                        f"Basic config for {ExchangeType.BYBIT} is not set. Please add `{ExchangeType.BYBIT}` in `basic_config`."
-                    )
+        # Validate each exchange's connectors
+        for exchange_id, connectors in exchange_connectors.items():
+            exchange = self._exchanges[exchange_id]
+            basic_config = self._config.basic_config.get(exchange_id)
 
-                else:
-                    if bybit_basic_config.testnet != account_type.is_testnet:
-                        raise EngineBuildError(
-                            f"The `testnet` setting of {ExchangeType.BYBIT} is not consistent with the public connector's account type `{account_type}`."
-                        )
-            elif isinstance(account_type, BinanceAccountType):
-                if (
-                    account_type.is_isolated_margin_or_margin
-                    or account_type.is_portfolio_margin
-                ):
-                    raise EngineBuildError(
-                        f"{account_type} is not supported for public connector."
-                    )
-                binance_basic_config = self._config.basic_config.get(
-                    ExchangeType.BINANCE
+            if not basic_config:
+                raise EngineBuildError(
+                    f"Basic config for {exchange_id} is not set. Please add `{exchange_id}` in `basic_config`."
                 )
-                if not binance_basic_config:
-                    raise EngineBuildError(
-                        f"Basic config for {ExchangeType.BINANCE} is not set. Please add `{ExchangeType.BINANCE}` in `basic_config`."
-                    )
-                else:
-                    if binance_basic_config.testnet != account_type.is_testnet:
-                        raise EngineBuildError(
-                            f"The `testnet` setting of {ExchangeType.BINANCE} is not consistent with the public connector's account type `{account_type}`."
-                        )
 
-            elif isinstance(account_type, OkxAccountType):
-                if okx_public_conn_count > 1:
-                    raise EngineBuildError(
-                        "Only one public connector is supported for OKX, please remove the extra public connector config."
-                    )
-                okx_basic_config = self._config.basic_config.get(ExchangeType.OKX)
-                if not okx_basic_config:
-                    raise EngineBuildError(
-                        f"Basic config for {ExchangeType.OKX} is not set. Please add `{ExchangeType.OKX}` in `basic_config`."
-                    )
-                else:
-                    if okx_basic_config.testnet != account_type.is_testnet:
-                        raise EngineBuildError(
-                            f"The `testnet` setting of {ExchangeType.OKX} is not consistent with the public connector's account type `{account_type}`."
-                        )
+            # Validate each connector configuration
+            for account_type in connectors.keys():
+                exchange.validate_public_connector_config(account_type, basic_config)
 
-                okx_public_conn_count += 1
-            else:
-                raise EngineBuildError(f"Unsupported account type: {account_type}")
+            # Validate connector limits
+            exchange.validate_public_connector_limits(connectors)
 
     def _build_public_connectors(self):
         for exchange_id, public_conn_configs in self._config.public_conn_config.items():
@@ -182,8 +187,9 @@ class Engine:
                         account_type=account_type,
                         exchange=exchange,
                         msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
-                        rate_limit=config.rate_limit,
+                        enable_rate_limit=config.enable_rate_limit,
                         custom_url=config.custom_url,
                     )
                     self._public_connectors[account_type] = public_connector
@@ -195,25 +201,56 @@ class Engine:
                         account_type=account_type,
                         exchange=exchange,
                         msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
-                        rate_limit=config.rate_limit,
+                        enable_rate_limit=config.enable_rate_limit,
                         custom_url=config.custom_url,
                     )
 
                     self._public_connectors[account_type] = public_connector
-
+                elif exchange_id == ExchangeType.BITGET:
+                    exchange: BitgetExchangeManager = self._exchanges[exchange_id]
+                    account_type: BitgetAccountType = config.account_type
+                    exchange.set_public_connector_account_type(account_type)
+                    public_connector = BitgetPublicConnector(
+                        account_type=account_type,
+                        exchange=exchange,
+                        msgbus=self._msgbus,
+                        clock=self._clock,
+                        task_manager=self._task_manager,
+                        enable_rate_limit=config.enable_rate_limit,
+                        custom_url=config.custom_url,
+                    )
+                    self._public_connectors[account_type] = public_connector
+                elif exchange_id == ExchangeType.HYPERLIQUID:
+                    exchange: HyperLiquidExchangeManager = self._exchanges[exchange_id]
+                    account_type: HyperLiquidAccountType = config.account_type
+                    exchange.set_public_connector_account_type(account_type)
+                    public_connector = HyperLiquidPublicConnector(
+                        account_type=account_type,
+                        exchange=exchange,
+                        msgbus=self._msgbus,
+                        clock=self._clock,
+                        task_manager=self._task_manager,
+                        enable_rate_limit=config.enable_rate_limit,
+                        custom_url=config.custom_url,
+                    )
+                    self._public_connectors[account_type] = public_connector
                 elif exchange_id == ExchangeType.OKX:
                     exchange: OkxExchangeManager = self._exchanges[exchange_id]
                     account_type: OkxAccountType = config.account_type
+                    exchange.set_public_connector_account_type(account_type)
                     public_connector = OkxPublicConnector(
                         account_type=account_type,
                         exchange=exchange,
                         msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
-                        rate_limit=config.rate_limit,
+                        enable_rate_limit=config.enable_rate_limit,
                         custom_url=config.custom_url,
                     )
                     self._public_connectors[account_type] = public_connector
+
         self._public_connector_check()
 
     def _build_private_connectors(self):
@@ -235,6 +272,7 @@ class Engine:
                             account_type=account_type,
                             exchange=self._exchanges[exchange_id],
                             msgbus=self._msgbus,
+                            clock=self._clock,
                             cache=self._cache,
                             task_manager=self._task_manager,
                             overwrite_balance=mock_conn_config.overwrite_balance,
@@ -247,10 +285,14 @@ class Engine:
                         self._private_connectors[account_type] = private_connector
                     elif mock_conn_config.account_type.is_inverse_mock:
                         # NOTE: currently not supported
-                        pass
+                        raise EngineBuildError(
+                            f"Mock connector for {account_type} is not supported."
+                        )
                     elif mock_conn_config.account_type.is_spot_mock:
                         # NOTE: currently not supported
-                        pass
+                        raise EngineBuildError(
+                            f"Mock connector for {account_type} is not supported."
+                        )
                     else:
                         raise EngineBuildError(
                             f"Unsupported account type: {account_type} for mock connector."
@@ -280,9 +322,15 @@ class Engine:
                             exchange=exchange,
                             account_type=account_type,
                             cache=self._cache,
+                            clock=self._clock,
                             msgbus=self._msgbus,
-                            rate_limit=config.rate_limit,
+                            registry=self._registry,
+                            enable_rate_limit=config.enable_rate_limit,
                             task_manager=self._task_manager,
+                            max_retries=config.max_retries,
+                            delay_initial_ms=config.delay_initial_ms,
+                            delay_max_ms=config.delay_max_ms,
+                            backoff_factor=config.backoff_factor,
                         )
                         self._private_connectors[account_type] = private_connector
 
@@ -303,9 +351,15 @@ class Engine:
                             exchange=exchange,
                             account_type=account_type,
                             cache=self._cache,
+                            clock=self._clock,
                             msgbus=self._msgbus,
-                            rate_limit=config.rate_limit,
+                            registry=self._registry,
+                            enable_rate_limit=config.enable_rate_limit,
                             task_manager=self._task_manager,
+                            max_retries=config.max_retries,
+                            delay_initial_ms=config.delay_initial_ms,
+                            delay_max_ms=config.delay_max_ms,
+                            backoff_factor=config.backoff_factor,
                         )
                         self._private_connectors[account_type] = private_connector
 
@@ -320,9 +374,57 @@ class Engine:
                                 exchange=exchange,
                                 account_type=account_type,
                                 cache=self._cache,
+                                clock=self._clock,
                                 msgbus=self._msgbus,
-                                rate_limit=config.rate_limit,
+                                registry=self._registry,
+                                enable_rate_limit=config.enable_rate_limit,
                                 task_manager=self._task_manager,
+                                max_retries=config.max_retries,
+                                delay_initial_ms=config.delay_initial_ms,
+                                delay_max_ms=config.delay_max_ms,
+                                backoff_factor=config.backoff_factor,
+                            )
+                            self._private_connectors[account_type] = private_connector
+                    case ExchangeType.BITGET:
+                        for config in private_conn_configs:
+                            exchange: BitgetExchangeManager = self._exchanges[
+                                exchange_id
+                            ]
+                            account_type: BitgetAccountType = config.account_type
+
+                            private_connector = BitgetPrivateConnector(
+                                exchange=exchange,
+                                account_type=account_type,
+                                cache=self._cache,
+                                msgbus=self._msgbus,
+                                clock=self._clock,
+                                registry=self._registry,
+                                enable_rate_limit=config.enable_rate_limit,
+                                task_manager=self._task_manager,
+                                max_retries=config.max_retries,
+                                delay_initial_ms=config.delay_initial_ms,
+                                delay_max_ms=config.delay_max_ms,
+                                backoff_factor=config.backoff_factor,
+                            )
+                            self._private_connectors[account_type] = private_connector
+
+                    case ExchangeType.HYPERLIQUID:
+                        for config in private_conn_configs:
+                            exchange: HyperLiquidExchangeManager = self._exchanges[
+                                exchange_id
+                            ]
+                            account_type: HyperLiquidAccountType = config.account_type
+
+                            private_connector = HyperLiquidPrivateConnector(
+                                exchange=exchange,
+                                account_type=account_type,
+                                cache=self._cache,
+                                clock=self._clock,
+                                msgbus=self._msgbus,
+                                registry=self._registry,
+                                enable_rate_limit=config.enable_rate_limit,
+                                task_manager=self._task_manager,
+                                max_slippage=config.max_slippage,
                             )
                             self._private_connectors[account_type] = private_connector
 
@@ -342,6 +444,10 @@ class Engine:
                 self._exchanges[exchange_id] = BinanceExchangeManager(config)
             elif exchange_id == ExchangeType.OKX:
                 self._exchanges[exchange_id] = OkxExchangeManager(config)
+            elif exchange_id == ExchangeType.HYPERLIQUID:
+                self._exchanges[exchange_id] = HyperLiquidExchangeManager(config)
+            elif exchange_id == ExchangeType.BITGET:
+                self._exchanges[exchange_id] = BitgetExchangeManager(config)
 
     def _build_custom_signal_recv(self):
         zmq_config = self._config.zero_mq_signal_config
@@ -378,6 +484,7 @@ class Engine:
                     market=exchange.market,
                     cache=self._cache,
                     msgbus=self._msgbus,
+                    clock=self._clock,
                     task_manager=self._task_manager,
                     registry=self._registry,
                     is_mock=self._config.is_mock,
@@ -392,6 +499,7 @@ class Engine:
                         market=exchange.market,
                         cache=self._cache,
                         msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
                         registry=self._registry,
                         is_mock=self._config.is_mock,
@@ -403,6 +511,7 @@ class Engine:
                         market=exchange.market,
                         cache=self._cache,
                         msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
                         registry=self._registry,
                         is_mock=self._config.is_mock,
@@ -414,120 +523,45 @@ class Engine:
                         market=exchange.market,
                         cache=self._cache,
                         msgbus=self._msgbus,
+                        clock=self._clock,
+                        task_manager=self._task_manager,
+                        registry=self._registry,
+                        is_mock=self._config.is_mock,
+                    )
+                    self._ems[exchange_id]._build(self._private_connectors)
+                case ExchangeType.HYPERLIQUID:
+                    exchange: HyperLiquidExchangeManager = self._exchanges[exchange_id]
+                    self._ems[exchange_id] = HyperLiquidExecutionManagementSystem(
+                        market=exchange.market,
+                        cache=self._cache,
+                        msgbus=self._msgbus,
+                        clock=self._clock,
+                        task_manager=self._task_manager,
+                        registry=self._registry,
+                        is_mock=self._config.is_mock,
+                    )
+                    self._ems[exchange_id]._build(self._private_connectors)
+                case ExchangeType.BITGET:
+                    exchange: BitgetExchangeManager = self._exchanges[exchange_id]
+                    self._ems[exchange_id] = BitgetExecutionManagementSystem(
+                        market=exchange.market,
+                        cache=self._cache,
+                        msgbus=self._msgbus,
+                        clock=self._clock,
                         task_manager=self._task_manager,
                         registry=self._registry,
                         is_mock=self._config.is_mock,
                     )
                     self._ems[exchange_id]._build(self._private_connectors)
 
-    def _build_oms(self):
-        for exchange_id in self._exchanges.keys():
-            match exchange_id:
-                case ExchangeType.BYBIT:
-                    self._oms[exchange_id] = BybitOrderManagementSystem(
-                        msgbus=self._msgbus,
-                        task_manager=self._task_manager,
-                        registry=self._registry,
-                    )
-                case ExchangeType.BINANCE:
-                    self._oms[exchange_id] = BinanceOrderManagementSystem(
-                        msgbus=self._msgbus,
-                        task_manager=self._task_manager,
-                        registry=self._registry,
-                    )
-                case ExchangeType.OKX:
-                    self._oms[exchange_id] = OkxOrderManagementSystem(
-                        msgbus=self._msgbus,
-                        task_manager=self._task_manager,
-                        registry=self._registry,
-                    )
-
     def _build(self):
         self._build_exchanges()
         self._build_public_connectors()
         self._build_private_connectors()
         self._build_ems()
-        self._build_oms()
         self._build_custom_signal_recv()
         self._is_built = True
 
-    def _instrument_id_to_account_type(
-        self, instrument_id: InstrumentId
-    ) -> AccountType:
-        match instrument_id.exchange:
-            case ExchangeType.BYBIT:
-                bybit_basic_config = self._config.basic_config.get(ExchangeType.BYBIT)
-                if not bybit_basic_config:
-                    raise EngineBuildError(
-                        f"Basic config for {ExchangeType.BYBIT} is not set. Please add `{ExchangeType.BYBIT}` in `basic_config`."
-                    )
-
-                is_testnet = bybit_basic_config.testnet
-
-                if instrument_id.is_spot:
-                    return (
-                        BybitAccountType.SPOT_TESTNET
-                        if is_testnet
-                        else BybitAccountType.SPOT
-                    )
-                elif instrument_id.is_linear:
-                    return (
-                        BybitAccountType.LINEAR_TESTNET
-                        if is_testnet
-                        else BybitAccountType.LINEAR
-                    )
-                elif instrument_id.is_inverse:
-                    return (
-                        BybitAccountType.INVERSE_TESTNET
-                        if is_testnet
-                        else BybitAccountType.INVERSE
-                    )
-                else:
-                    raise ValueError(
-                        f"Unsupported instrument type: {instrument_id.type}"
-                    )
-            case ExchangeType.BINANCE:
-                binance_basic_config = self._config.basic_config.get(
-                    ExchangeType.BINANCE
-                )
-                if not binance_basic_config:
-                    raise EngineBuildError(
-                        f"Basic config for {ExchangeType.BINANCE} is not set. Please add `{ExchangeType.BINANCE}` in `basic_config`."
-                    )
-
-                is_testnet = binance_basic_config.testnet
-
-                if instrument_id.is_spot:
-                    return (
-                        BinanceAccountType.SPOT_TESTNET
-                        if is_testnet
-                        else BinanceAccountType.SPOT
-                    )
-                elif instrument_id.is_linear:
-                    return (
-                        BinanceAccountType.USD_M_FUTURE_TESTNET
-                        if is_testnet
-                        else BinanceAccountType.USD_M_FUTURE
-                    )
-                elif instrument_id.is_inverse:
-                    return (
-                        BinanceAccountType.COIN_M_FUTURE_TESTNET
-                        if is_testnet
-                        else BinanceAccountType.COIN_M_FUTURE
-                    )
-                else:
-                    raise ValueError(
-                        f"Unsupported instrument type: {instrument_id.type}"
-                    )
-            case ExchangeType.OKX:
-                account_types = self._config.public_conn_config.get(ExchangeType.OKX)
-                if not account_types:
-                    raise EngineBuildError(
-                        f"Public connector config for {ExchangeType.OKX} is not set. Please add `{ExchangeType.OKX}` in `public_conn_config`."
-                    )
-
-                return account_types[0].account_type
-
     async def _start_connectors(self):
         for connector in self._private_connectors.values():
             await connector.connect()
@@ -539,7 +573,8 @@ class Engine:
 
                     for symbol in sub:
                         instrument_id = InstrumentId.from_str(symbol)
-                        account_type = self._instrument_id_to_account_type(
+                        exchange = self._exchanges[instrument_id.exchange]
+                        account_type = exchange.instrument_id_to_account_type(
                             instrument_id
                         )
 
@@ -557,7 +592,8 @@ class Engine:
 
                     for symbol in sub:
                         instrument_id = InstrumentId.from_str(symbol)
-                        account_type = self._instrument_id_to_account_type(
+                        exchange = self._exchanges[instrument_id.exchange]
+                        account_type = exchange.instrument_id_to_account_type(
                             instrument_id
                         )
                         account_symbols[account_type].append(instrument_id.symbol)
@@ -575,7 +611,8 @@ class Engine:
                     for interval, symbols in sub.items():
                         for symbol in symbols:
                             instrument_id = InstrumentId.from_str(symbol)
-                            account_type = self._instrument_id_to_account_type(
+                            exchange = self._exchanges[instrument_id.exchange]
+                            account_type = exchange.instrument_id_to_account_type(
                                 instrument_id
                             )
                             account_symbols[account_type].append(instrument_id.symbol)
@@ -593,7 +630,8 @@ class Engine:
                     for level, symbols in sub.items():
                         for symbol in symbols:
                             instrument_id = InstrumentId.from_str(symbol)
-                            account_type = self._instrument_id_to_account_type(
+                            exchange = self._exchanges[instrument_id.exchange]
+                            account_type = exchange.instrument_id_to_account_type(
                                 instrument_id
                             )
                             account_symbols[account_type].append(instrument_id.symbol)
@@ -610,7 +648,8 @@ class Engine:
 
                     for symbol in sub:
                         instrument_id = InstrumentId.from_str(symbol)
-                        account_type = self._instrument_id_to_account_type(
+                        exchange = self._exchanges[instrument_id.exchange]
+                        account_type = exchange.instrument_id_to_account_type(
                             instrument_id
                         )
 
@@ -628,7 +667,8 @@ class Engine:
 
                     for symbol in sub:
                         instrument_id = InstrumentId.from_str(symbol)
-                        account_type = self._instrument_id_to_account_type(
+                        exchange = self._exchanges[instrument_id.exchange]
+                        account_type = exchange.instrument_id_to_account_type(
                             instrument_id
                         )
 
@@ -646,7 +686,8 @@ class Engine:
 
                     for symbol in sub:
                         instrument_id = InstrumentId.from_str(symbol)
-                        account_type = self._instrument_id_to_account_type(
+                        exchange = self._exchanges[instrument_id.exchange]
+                        account_type = exchange.instrument_id_to_account_type(
                             instrument_id
                         )
 
@@ -672,35 +713,78 @@ class Engine:
         self._strategy._scheduler.start()
         self._scheduler_started = True
 
+    def _start_auto_flush_thread(self):
+        if self._config.log_config.auto_flush_sec > 0:
+            self._log.debug(
+                f"Starting auto flush thread with interval: {self._config.log_config.auto_flush_sec}s"
+            )
+            self._auto_flush_thread = threading.Thread(
+                target=self._auto_flush_worker, daemon=True
+            )
+            self._auto_flush_thread.start()
+        else:
+            self._log.debug("Auto flush disabled (auto_flush_sec = 0)")
+
+    def _auto_flush_worker(self):
+        self._log.debug("Auto flush worker thread started")
+        while not self._auto_flush_stop_event.wait(
+            self._config.log_config.auto_flush_sec
+        ):
+            self._log.debug("Performing auto logger flush")
+            nautilus_pyo3.logger_flush()
+        self._log.debug("Auto flush worker thread stopped")
+
     async def _start(self):
-        await self._cache.start()  # NOTE: this must be the first thing to call
         await self._start_oms()
         await self._start_ems()
         await self._start_connectors()
         if self._custom_signal_recv:
             await self._custom_signal_recv.start()
         self._start_scheduler()
+        self._start_auto_flush_thread()
         await self._task_manager.wait()
 
     async def _dispose(self):
         if self._scheduler_started:
-            self._strategy._scheduler.shutdown()
+            try:
+                # Remove all jobs first to prevent new executions
+                self._strategy._scheduler.remove_all_jobs()
+                # Short delay to allow running jobs to complete
+                await asyncio.sleep(0.05)
+                # Shutdown without waiting for jobs to complete
+                self._strategy._scheduler.shutdown(wait=False)
+            except (asyncio.CancelledError, RuntimeError):
+                # Suppress expected shutdown exceptions
+                pass
+
+        # Stop auto flush thread
+        if self._auto_flush_thread and self._auto_flush_thread.is_alive():
+            self._log.debug("Stopping auto flush thread")
+            self._auto_flush_stop_event.set()
+            self._auto_flush_thread.join(timeout=0.1)
+            if self._auto_flush_thread.is_alive():
+                self._log.warning("Auto flush thread did not stop within timeout")
+            else:
+                self._log.debug("Auto flush thread stopped successfully")
+
         for connector in self._public_connectors.values():
             await connector.disconnect()
         for connector in self._private_connectors.values():
             await connector.disconnect()
 
-        await asyncio.sleep(0.1)  # NOTE: wait for the websocket to disconnect
+        await asyncio.sleep(0.2)  # NOTE: wait for the websocket to disconnect
 
         await self._task_manager.cancel()
         await self._cache.close()
 
     def start(self):
         self._build()
-        self._strategy.on_start()
+        self._loop.run_until_complete(self._cache.start())  # Initialize cache
+        self._strategy._on_start()
         self._loop.run_until_complete(self._start())
 
     def dispose(self):
-        self._strategy.on_stop()
+        self._strategy._on_stop()
         self._loop.run_until_complete(self._dispose())
         self._loop.close()
+        nautilus_pyo3.logger_flush()
