@@ -1,21 +1,20 @@
 import msgspec
 from typing import Dict, List
-from decimal import Decimal
 from nexustrader.exchange.okx import OkxAccountType
 from nexustrader.exchange.okx.websockets import OkxWSClient
 from nexustrader.exchange.okx.exchange import OkxExchangeManager
 from nexustrader.exchange.okx.schema import OkxWsGeneralMsg
+from nexustrader.exchange.okx.oms import OkxOrderManagementSystem
 from nexustrader.schema import (
     Trade,
     BookL1,
     Kline,
-    Order,
-    Position,
     BookL2,
     IndexPrice,
     FundingRate,
     MarkPrice,
     KlineList,
+    Ticker,
 )
 from nexustrader.exchange.okx.schema import (
     OkxMarket,
@@ -25,31 +24,23 @@ from nexustrader.exchange.okx.schema import (
     OkxWsIndexTickerMsg,
     OkxWsFundingRateMsg,
     OkxWsMarkPriceMsg,
-    OkxWsOrderMsg,
-    OkxWsPositionMsg,
-    OkxWsAccountMsg,
-    OkxBalanceResponse,
-    OkxPositionResponse,
     OkxCandlesticksResponse,
     OkxCandlesticksResponseData,
     OkxWsBook5Msg,
+    OkxTickersResponse,
+    OkxIndexCandlesticksResponseData,
 )
 from nexustrader.constants import (
-    OrderStatus,
-    TimeInForce,
-    PositionSide,
     KlineInterval,
-    TriggerType,
     BookLevel,
 )
 from nexustrader.base import PublicConnector, PrivateConnector
-from nexustrader.core.nautilius_core import MessageBus
+from nexustrader.core.nautilius_core import MessageBus, LiveClock
 from nexustrader.core.cache import AsyncCache
-from nexustrader.core.entity import TaskManager, RateLimit
+from nexustrader.core.entity import TaskManager
+from nexustrader.core.registry import OrderRegistry
 from nexustrader.exchange.okx.rest_api import OkxApiClient
-from nexustrader.constants import OrderSide, OrderType
 from nexustrader.exchange.okx.constants import (
-    OkxTdMode,
     OkxEnumParser,
     OkxKlineInterval,
 )
@@ -65,9 +56,10 @@ class OkxPublicConnector(PublicConnector):
         account_type: OkxAccountType,
         exchange: OkxExchangeManager,
         msgbus: MessageBus,
+        clock: LiveClock,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
         custom_url: str | None = None,
+        enable_rate_limit: bool = True,
     ):
         super().__init__(
             account_type=account_type,
@@ -79,13 +71,16 @@ class OkxPublicConnector(PublicConnector):
                 handler=self._ws_msg_handler,
                 task_manager=task_manager,
                 custom_url=custom_url,
+                clock=clock,
             ),
             msgbus=msgbus,
+            clock=clock,
             api_client=OkxApiClient(
+                clock=clock,
                 testnet=account_type.is_testnet,
+                enable_rate_limit=enable_rate_limit,
             ),
             task_manager=task_manager,
-            rate_limit=rate_limit,
         )
         self._business_ws_client = OkxWSClient(
             account_type=account_type,
@@ -93,6 +88,7 @@ class OkxPublicConnector(PublicConnector):
             task_manager=task_manager,
             business_url=True,
             custom_url=custom_url,
+            clock=clock,
         )
         self._ws_msg_general_decoder = msgspec.json.Decoder(OkxWsGeneralMsg)
         self._ws_msg_bbo_tbt_decoder = msgspec.json.Decoder(OkxWsBboTbtMsg)
@@ -103,26 +99,64 @@ class OkxPublicConnector(PublicConnector):
         self._ws_msg_mark_price_decoder = msgspec.json.Decoder(OkxWsMarkPriceMsg)
         self._ws_msg_funding_rate_decoder = msgspec.json.Decoder(OkxWsFundingRateMsg)
 
-    async def _get_api_v5_market_history_candles(
+    def request_ticker(
         self,
-        instId: str,
-        bar: str,
-        after: str | None = None,
-        before: str | None = None,
-        limit: int | None = None,
-    ) -> OkxCandlesticksResponse:
-        if self._limiter:
-            await self._limiter.acquire()
+        symbol: str,
+    ) -> Ticker:
+        """Request 24hr ticker data"""
+        market = self._market.get(symbol)
+        if not market:
+            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
 
-        return await self._api_client.get_api_v5_market_history_candles(
-            instId=instId,
-            bar=bar,
-            after=after,
-            before=before,
-            limit=limit,
+        ticker_response: OkxTickersResponse = self._api_client.get_api_v5_market_ticker(
+            inst_id=market.id
+        )
+        for item in ticker_response.data:
+            ticker = Ticker(
+                exchange=self._exchange_id,
+                symbol=symbol,
+                last_price=float(item.last) if item.last else 0.0,
+                timestamp=int(item.ts),
+                volume=float(item.vol24h) if item.vol24h else 0.0,
+                volumeCcy=float(item.volCcy24h) if item.volCcy24h else 0.0,
+            )
+            return ticker
+
+    def request_all_tickers(
+        self,
+    ) -> Dict[str, Ticker]:
+        """Request 24hr ticker data for multiple symbols"""
+        spot_tickers_response: OkxTickersResponse = (
+            self._api_client.get_api_v5_market_tickers(inst_type="SPOT")
+        )
+        swap_tickers_response: OkxTickersResponse = (
+            self._api_client.get_api_v5_market_tickers(inst_type="SWAP")
+        )
+        future_tickers_response: OkxTickersResponse = (
+            self._api_client.get_api_v5_market_tickers(inst_type="FUTURES")
         )
 
-    async def _request_klines(
+        tickers = {}
+        for item in (
+            spot_tickers_response.data
+            + swap_tickers_response.data
+            + future_tickers_response.data
+        ):
+            symbol = self._market_id.get(item.instId)
+            if not symbol:
+                continue
+            tickers[symbol] = Ticker(
+                exchange=self._exchange_id,
+                symbol=symbol,
+                last_price=float(item.last) if item.last else 0.0,
+                timestamp=int(item.ts),
+                volume=float(item.vol24h) if item.vol24h else 0.0,
+                volumeCcy=float(item.volCcy24h) if item.volCcy24h else 0.0,
+            )
+
+        return tickers
+
+    def request_index_klines(
         self,
         symbol: str,
         interval: KlineInterval,
@@ -140,7 +174,114 @@ class OkxPublicConnector(PublicConnector):
 
         # First request to get the most recent data using before parameter
         klines_response: OkxCandlesticksResponse = (
-            await self._get_api_v5_market_history_candles(
+            self._api_client.get_api_v5_market_history_index_candles(
+                instId=self._market[symbol].id,
+                bar=okx_interval.value,
+                limit=100,  # Maximum allowed by the API is 100
+                before="0",  # Get the latest klines
+            )
+        )
+
+        response_klines = sorted(klines_response.data, key=lambda x: int(x.ts))
+        klines = [
+            self._handle_index_candlesticks(
+                symbol=symbol, interval=interval, kline=kline
+            )
+            for kline in response_klines
+            if int(kline.ts) not in seen_timestamps
+        ]
+        all_klines.extend(klines)
+        seen_timestamps.update(int(kline.ts) for kline in response_klines)
+
+        # Continue fetching older data using after parameter if needed
+        if (
+            start_time is not None
+            and all_klines
+            and int(all_klines[0].timestamp) > start_time
+        ):
+            while True:
+                # Use the oldest timestamp we have as the 'after' parameter
+                oldest_timestamp = (
+                    min(int(kline.ts) for kline in response_klines)
+                    if response_klines
+                    else None
+                )
+
+                if not oldest_timestamp or (
+                    start_time is not None and oldest_timestamp <= start_time
+                ):
+                    break
+
+                klines_response = (
+                    self._api_client.get_api_v5_market_history_index_candles(
+                        instId=self._market[symbol].id,
+                        bar=okx_interval.value,
+                        limit=100,
+                        after=str(oldest_timestamp),  # Get klines before this timestamp
+                    )
+                )
+
+                response_klines = sorted(klines_response.data, key=lambda x: int(x.ts))
+                if not response_klines:
+                    break
+
+                # Process klines and filter out duplicates
+                new_klines = [
+                    self._handle_index_candlesticks(
+                        symbol=symbol, interval=interval, kline=kline
+                    )
+                    for kline in response_klines
+                    if int(kline.ts) not in seen_timestamps
+                ]
+
+                if not new_klines:
+                    break
+
+                all_klines = (
+                    new_klines + all_klines
+                )  # Prepend new klines as they are older
+                seen_timestamps.update(int(kline.ts) for kline in response_klines)
+
+        # Apply limit if specified
+        if limit is not None and len(all_klines) > limit:
+            all_klines = all_klines[-limit:]  # Take the most recent klines
+
+        if end_time:
+            all_klines = [kline for kline in all_klines if kline.timestamp < end_time]
+
+        kline_list = KlineList(
+            all_klines,
+            fields=[
+                "timestamp",
+                "symbol",
+                "open",
+                "high",
+                "low",
+                "close",
+                "confirm",
+            ],
+        )
+        return kline_list
+
+    def request_klines(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+        limit: int | None = None,
+        start_time: int | None = None,
+        end_time: int | None = None,
+    ) -> KlineList:
+        market = self._market.get(symbol)
+        if not market:
+            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
+
+        okx_interval = OkxEnumParser.to_okx_kline_interval(interval)
+        all_klines: list[Kline] = []
+        seen_timestamps: set[int] = set()
+
+        # First request to get the most recent data using before parameter
+        klines_response: OkxCandlesticksResponse = (
+            self._api_client.get_api_v5_market_history_candles(
                 instId=self._market[symbol].id,
                 bar=okx_interval.value,
                 limit=100,  # Maximum allowed by the API is 100
@@ -176,7 +317,7 @@ class OkxPublicConnector(PublicConnector):
                 ):
                     break
 
-                klines_response = await self._get_api_v5_market_history_candles(
+                klines_response = self._api_client.get_api_v5_market_history_candles(
                     instId=self._market[symbol].id,
                     bar=okx_interval.value,
                     limit=100,
@@ -227,24 +368,6 @@ class OkxPublicConnector(PublicConnector):
         )
         return kline_list
 
-    def request_klines(
-        self,
-        symbol: str,
-        interval: KlineInterval,
-        limit: int | None = None,
-        start_time: int | None = None,
-        end_time: int | None = None,
-    ) -> list[Kline]:
-        return self._task_manager.run_sync(
-            self._request_klines(
-                symbol=symbol,
-                interval=interval,
-                limit=limit,
-                start_time=start_time,
-                end_time=end_time,
-            )
-        )
-
     async def subscribe_trade(self, symbol: str | List[str]):
         symbols = []
         if isinstance(symbol, str):
@@ -359,7 +482,7 @@ class OkxPublicConnector(PublicConnector):
     def _ws_msg_handler(self, raw: bytes):
         if raw == b"pong":
             self._ws_client._transport.notify_user_specific_pong_received()
-            self._log.debug(f"Pong received:{str(raw)}")
+            self._log.debug(f"Pong received:{raw.decode()}")
             return
         try:
             ws_msg: OkxWsGeneralMsg = self._ws_msg_general_decoder.decode(raw)
@@ -501,6 +624,9 @@ class OkxPublicConnector(PublicConnector):
         symbol = self._market_id[id]
 
         for d in msg.data:
+            if not d.bids or not d.asks:
+                continue
+
             bookl1 = BookL1(
                 exchange=self._exchange_id,
                 symbol=symbol,
@@ -512,6 +638,25 @@ class OkxPublicConnector(PublicConnector):
             )
             self._msgbus.publish(topic="bookl1", msg=bookl1)
 
+    def _handle_index_candlesticks(
+        self,
+        symbol: str,
+        interval: KlineInterval,
+        kline: OkxIndexCandlesticksResponseData,
+    ) -> Kline:
+        return Kline(
+            exchange=self._exchange_id,
+            symbol=symbol,
+            interval=interval,
+            open=float(kline.o),
+            high=float(kline.h),
+            low=float(kline.l),
+            close=float(kline.c),
+            start=int(kline.ts),
+            timestamp=self._clock.timestamp_ms(),
+            confirm=False if int(kline.confirm) == 0 else True,
+        )
+
     def _handle_candlesticks(
         self, symbol: str, interval: KlineInterval, kline: OkxCandlesticksResponseData
     ) -> Kline:
@@ -536,446 +681,66 @@ class OkxPublicConnector(PublicConnector):
 
 
 class OkxPrivateConnector(PrivateConnector):
-    _ws_client: OkxWSClient
     _api_client: OkxApiClient
     _account_type: OkxAccountType
     _market: Dict[str, OkxMarket]
     _market_id: Dict[str, str]
+    _oms: OkxOrderManagementSystem
 
     def __init__(
         self,
-        exchange: OkxExchangeManager,
         account_type: OkxAccountType,
+        exchange: OkxExchangeManager,
         cache: AsyncCache,
+        registry: OrderRegistry,
+        clock: LiveClock,
         msgbus: MessageBus,
         task_manager: TaskManager,
-        rate_limit: RateLimit | None = None,
+        enable_rate_limit: bool = True,
+        **kwargs,
     ):
         if not exchange.api_key or not exchange.secret or not exchange.passphrase:
             raise ValueError(
                 "API key, secret, and passphrase are required for private endpoints"
             )
 
+        api_client = OkxApiClient(
+            clock=clock,
+            api_key=exchange.api_key,
+            secret=exchange.secret,
+            passphrase=exchange.passphrase,
+            testnet=account_type.is_testnet,
+            enable_rate_limit=enable_rate_limit,
+            **kwargs,
+        )
+
+        oms = OkxOrderManagementSystem(
+            account_type=account_type,
+            api_key=exchange.api_key,
+            secret=exchange.secret,
+            passphrase=exchange.passphrase,
+            market=exchange.market,
+            market_id=exchange.market_id,
+            registry=registry,
+            cache=cache,
+            api_client=api_client,
+            exchange_id=exchange.exchange_id,
+            clock=clock,
+            msgbus=msgbus,
+            task_manager=task_manager,
+            enable_rate_limit=enable_rate_limit,
+        )
+
         super().__init__(
             account_type=account_type,
             market=exchange.market,
-            market_id=exchange.market_id,
-            exchange_id=exchange.exchange_id,
-            ws_client=OkxWSClient(
-                account_type=account_type,
-                handler=self._ws_msg_handler,
-                task_manager=task_manager,
-                api_key=exchange.api_key,
-                secret=exchange.secret,
-                passphrase=exchange.passphrase,
-            ),
-            api_client=OkxApiClient(
-                api_key=exchange.api_key,
-                secret=exchange.secret,
-                passphrase=exchange.passphrase,
-                testnet=account_type.is_testnet,
-            ),
-            msgbus=msgbus,
-            cache=cache,
-            rate_limit=rate_limit,
+            api_client=api_client,
             task_manager=task_manager,
-        )
-
-        self._decoder_ws_general_msg = msgspec.json.Decoder(OkxWsGeneralMsg)
-        self._decoder_ws_order_msg = msgspec.json.Decoder(OkxWsOrderMsg, strict=False)
-        self._decoder_ws_position_msg = msgspec.json.Decoder(
-            OkxWsPositionMsg, strict=False
-        )
-        self._decoder_ws_account_msg = msgspec.json.Decoder(
-            OkxWsAccountMsg, strict=False
+            oms=oms,
         )
 
     async def connect(self):
-        await super().connect()
-        await self._ws_client.subscribe_orders()
-        await self._ws_client.subscribe_positions()
-        await self._ws_client.subscribe_account()
-        # await self._ws_client.subscribe_account_position()
-        # await self._ws_client.subscribe_fills()
-
-    async def _init_account_balance(self):
-        res: OkxBalanceResponse = await self._api_client.get_api_v5_account_balance()
-        for data in res.data:
-            self._cache._apply_balance(self._account_type, data.parse_to_balances())
-
-    async def _init_position(self):
-        res: OkxPositionResponse = await self._api_client.get_api_v5_account_positions()
-        for data in res.data:
-            side = data.posSide.parse_to_position_side()
-            if side == PositionSide.FLAT:
-                signed_amount = Decimal(data.pos)
-                if signed_amount > 0:
-                    side = PositionSide.LONG
-                elif signed_amount < 0:
-                    side = PositionSide.SHORT
-                else:
-                    side = None
-            elif side == PositionSide.LONG:
-                signed_amount = Decimal(data.pos)
-            elif side == PositionSide.SHORT:
-                signed_amount = -Decimal(data.pos)
-
-            symbol = self._market_id[data.instId]
-
-            position = Position(
-                symbol=symbol,
-                exchange=self._exchange_id,
-                side=side,
-                signed_amount=signed_amount,
-                entry_price=float(data.avgPx) if data.avgPx else 0,
-                unrealized_pnl=float(data.upl) if data.upl else 0,
-                realized_pnl=float(data.realizedPnl) if data.realizedPnl else 0,
-            )
-            self._cache._apply_position(position)
-
-    def _handle_event_msg(self, msg: OkxWsGeneralMsg):
-        if msg.event == "error":
-            self._log.error(msg)
-        elif msg.event == "login":
-            self._log.debug("Login success")
-        elif msg.event == "subscribe":
-            self._log.debug(f"Subscribed to {msg.arg.channel}")
-
-    def _ws_msg_handler(self, raw: bytes):
-        if raw == b"pong":
-            self._ws_client._transport.notify_user_specific_pong_received()
-            self._log.debug(f"Pong received: {str(raw)}")
-            return
-        try:
-            ws_msg: OkxWsGeneralMsg = self._decoder_ws_general_msg.decode(raw)
-            if ws_msg.is_event_msg:
-                self._handle_event_msg(ws_msg)
-            else:
-                channel = ws_msg.arg.channel
-                if channel == "orders":
-                    self._handle_orders(raw)
-                elif channel == "positions":
-                    self._handle_positions(raw)
-                elif channel == "account":
-                    self._handle_account(raw)
-        except msgspec.DecodeError as e:
-            self._log.error(f"Error decoding message: {str(raw)} {e}")
-
-    def _handle_orders(self, raw: bytes):
-        msg: OkxWsOrderMsg = self._decoder_ws_order_msg.decode(raw)
-        self._log.debug(f"Order update: {str(msg)}")
-        for data in msg.data:
-            symbol = self._market_id[data.instId]
-
-            market = self._market[symbol]
-
-            if not market.spot:
-                ct_val = Decimal(market.info.ctVal)  # contract size
-            else:
-                ct_val = Decimal("1")
-
-            order = Order(
-                exchange=self._exchange_id,
-                symbol=symbol,
-                status=OkxEnumParser.parse_order_status(data.state),
-                id=data.ordId,
-                amount=Decimal(data.sz) * ct_val,
-                filled=Decimal(data.accFillSz) * ct_val,
-                client_order_id=data.clOrdId,
-                timestamp=data.uTime,
-                type=OkxEnumParser.parse_order_type(data.ordType),
-                side=OkxEnumParser.parse_order_side(data.side),
-                time_in_force=OkxEnumParser.parse_time_in_force(data.ordType),
-                price=float(data.px) if data.px else None,
-                average=float(data.avgPx) if data.avgPx else None,
-                last_filled_price=float(data.fillPx) if data.fillPx else None,
-                last_filled=Decimal(data.fillSz) * ct_val
-                if data.fillSz
-                else Decimal(0),
-                remaining=Decimal(data.sz) * ct_val - Decimal(data.accFillSz) * ct_val,
-                fee=Decimal(data.fee),  # accumalated fee
-                fee_currency=data.feeCcy,  # accumalated fee currency
-                cost=Decimal(data.avgPx) * Decimal(data.fillSz) * ct_val,
-                cum_cost=Decimal(data.avgPx) * Decimal(data.accFillSz) * ct_val,
-                reduce_only=data.reduceOnly,
-                position_side=OkxEnumParser.parse_position_side(data.posSide),
-            )
-            self._msgbus.send(endpoint="okx.order", msg=order)
-
-    def _handle_positions(self, raw: bytes):
-        position_msg = self._decoder_ws_position_msg.decode(raw)
-        self._log.debug(f"Okx Position Msg: {str(position_msg)}")
-
-        for data in position_msg.data:
-            symbol = self._market_id[data.instId]
-            market = self._market[symbol]
-
-            ct_val = Decimal(market.info.ctVal)
-
-            side = data.posSide.parse_to_position_side()
-            if side == PositionSide.LONG:
-                signed_amount = Decimal(data.pos)
-            elif side == PositionSide.SHORT:
-                signed_amount = -Decimal(data.pos)
-            elif side == PositionSide.FLAT:
-                # one way mode, posSide always is 'net' from OKX ws msg, and pos amount is signed
-                signed_amount = Decimal(data.pos)
-                if signed_amount > 0:
-                    side = PositionSide.LONG
-                elif signed_amount < 0:
-                    side = PositionSide.SHORT
-                else:
-                    side = None
-            else:
-                self._log.warn(f"Invalid position side: {side}")
-
-            position = Position(
-                symbol=symbol,
-                exchange=self._exchange_id,
-                side=side,
-                signed_amount=signed_amount * ct_val,
-                entry_price=float(data.avgPx) if data.avgPx else 0,
-                unrealized_pnl=float(data.upl) if data.upl else 0,
-                realized_pnl=float(data.realizedPnl) if data.realizedPnl else 0,
-            )
-            self._log.debug(f"Position updated: {str(position)}")
-            self._cache._apply_position(position)
-
-    def _handle_account(self, raw: bytes):
-        account_msg: OkxWsAccountMsg = self._decoder_ws_account_msg.decode(raw)
-        self._log.debug(f"Account update: {str(account_msg)}")
-
-        for data in account_msg.data:
-            balances = data.parse_to_balance()
-            self._cache._apply_balance(self._account_type, balances)
-
-    def _get_td_mode(self, market: OkxMarket):
-        return OkxTdMode.CASH if market.spot else OkxTdMode.CROSS
-
-    async def create_stop_loss_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        pass
-
-    async def create_take_profit_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        trigger_price: Decimal,
-        trigger_type: TriggerType = TriggerType.LAST_PRICE,
-        price: Decimal | None = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide | None = None,
-        **kwargs,
-    ) -> Order:
-        pass
-
-    async def create_order(
-        self,
-        symbol: str,
-        side: OrderSide,
-        type: OrderType,
-        amount: Decimal,
-        price: Decimal = None,
-        time_in_force: TimeInForce = TimeInForce.GTC,
-        position_side: PositionSide = None,
-        **kwargs,
-    ):
-        if self._limiter:
-            await self._limiter.acquire()
-
-        market = self._market.get(symbol)
-        if not market:
-            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-        symbol = market.id
-
-        td_mode = kwargs.pop("td_mode", None)
-        if not td_mode:
-            td_mode = self._get_td_mode(market)
-
-        if not market.spot:
-            ct_val = Decimal(market.info.ctVal)  # contract size
-            sz = format(amount / ct_val, "f")
-        else:
-            sz = str(amount)
-
-        params = {
-            "inst_id": symbol,
-            "td_mode": td_mode.value,
-            "side": OkxEnumParser.to_okx_order_side(side).value,
-            "ord_type": OkxEnumParser.to_okx_order_type(type, time_in_force).value,
-            "sz": sz,
-            "tag": "f50cdd72d3b6BCDE",
-        }
-
-        if type == OrderType.LIMIT:
-            if not price:
-                raise ValueError("Price is required for limit order")
-            params["px"] = str(price)
-        else:
-            if market.spot:
-                params["tgtCcy"] = "base_ccy"
-
-        if position_side:
-            params["posSide"] = OkxEnumParser.to_okx_position_side(position_side).value
-
-        reduce_only = kwargs.pop("reduceOnly", False) or kwargs.pop(
-            "reduce_only", False
-        )
-        if reduce_only:
-            params["reduceOnly"] = True
-
-        params.update(kwargs)
-
-        try:
-            res = await self._api_client.post_api_v5_trade_order(**params)
-            res = res.data[0]
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.ordId,
-                client_order_id=res.clOrdId,
-                timestamp=int(res.ts),
-                symbol=market.symbol,
-                type=type,
-                side=side,
-                amount=amount,
-                price=float(price) if price else None,
-                time_in_force=time_in_force,
-                position_side=position_side,
-                status=OrderStatus.PENDING,
-                filled=Decimal(0),
-                remaining=amount,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{e.__class__.__name__}: {str(e)}"
-            self._log.error(f"Error creating order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=market.symbol,
-                type=type,
-                side=side,
-                amount=amount,
-                price=float(price) if price else None,
-                time_in_force=time_in_force,
-                position_side=position_side,
-                status=OrderStatus.FAILED,
-                filled=Decimal(0),
-                remaining=amount,
-            )
-            return order
-
-    async def cancel_order(self, symbol: str, order_id: str, **kwargs):
-        if self._limiter:
-            await self._limiter.acquire()
-
-        market = self._market.get(symbol)
-        if not market:
-            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-        symbol = market.id
-
-        params = {"inst_id": symbol, "ord_id": order_id, **kwargs}
-
-        try:
-            res = await self._api_client.post_api_v5_trade_cancel_order(**params)
-            res = res.data[0]
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.ordId,
-                client_order_id=res.clOrdId,
-                timestamp=int(res.ts),
-                symbol=symbol,
-                status=OrderStatus.CANCELING,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{type(e).__name__}: {str(e)}"
-            self._log.error(f"Error canceling order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=symbol,
-                status=OrderStatus.CANCEL_FAILED,
-            )
-            return order
-
-    async def modify_order(
-        self,
-        symbol: str,
-        order_id: str,
-        side: OrderSide | None = None,
-        price: Decimal | None = None,
-        amount: Decimal | None = None,
-        **kwargs,
-    ):
-        # NOTE: modify order with side is not supported by OKX
-        if price is None and amount is None:
-            raise ValueError("Either price or amount must be provided")
-
-        if self._limiter:
-            await self._limiter.acquire()
-
-        market = self._market.get(symbol)
-        if not market:
-            raise ValueError(f"Symbol {symbol} formated wrongly, or not supported")
-        symbol = market.id
-
-        if not market.spot:
-            ct_val = Decimal(market.info.ctVal)  # contract size
-            sz = format(amount / ct_val, "f") if amount else None
-        else:
-            sz = str(amount) if amount else None
-
-        params = {
-            "instId": symbol,
-            "ordId": order_id,
-            "newPx": str(price) if price else None,
-            "newSz": sz,
-            **kwargs,
-        }
-
-        try:
-            res = await self._api_client.post_api_v5_trade_amend_order(**params)
-            res = res.data[0]
-            order = Order(
-                exchange=self._exchange_id,
-                id=res.ordId,
-                client_order_id=res.clOrdId,
-                timestamp=int(res.ts),
-                symbol=symbol,
-                status=OrderStatus.PENDING,
-            )
-            return order
-        except Exception as e:
-            error_msg = f"{type(e).__name__}: {str(e)}"
-            self._log.error(f"Error modifying order: {error_msg} params: {str(params)}")
-            order = Order(
-                exchange=self._exchange_id,
-                timestamp=self._clock.timestamp_ms(),
-                symbol=kwargs.get("symbol"),
-                status=OrderStatus.FAILED,
-            )
-            return order
-
-    async def cancel_all_orders(self, symbol: str) -> bool:
-        """
-        no cancel all orders in OKX
-        """
-        pass
-
-    async def disconnect(self):
-        await super().disconnect()
-        await self._api_client.close_session()
+        await self._oms._ws_api_client.connect()
+        await self._oms._ws_client.subscribe_orders()
+        await self._oms._ws_client.subscribe_positions()
+        await self._oms._ws_client.subscribe_account()
