@@ -28,13 +28,11 @@ class OkxRequestError(Exception):
 
     def __init__(self, error_code: int, status_code: int | None, message: str | None):
         super().__init__(message)
-        self.error_code = error_code
+        self.code = error_code
         self.status_code = status_code
         self.message = message
 
     def __repr__(self) -> str:
-        return (
-            f"{type(self).__name__}(code={self.error_code}, message='{self.message}')"
-        )
+        return f"{type(self).__name__}(code={self.code}, message='{self.message}')"
 
     __str__ = __repr__
