@@ -14,6 +14,11 @@ from nexustrader.exchange.okx.constants import (
     OkxTdMode,
     OkxOrderStatus,
     OkxSavingsPurchaseRedemptSide,
+    OkxAcctLv,
+    OkxPositionMode,
+    OkxTriggerType,
+    OkxWsApiOp,
+    restore_uuid_hyphens,
 )
 
 
@@ -37,6 +42,18 @@ class OkxWsGeneralMsg(msgspec.Struct):
     def is_event_msg(self) -> bool:
         return self.event is not None
 
+    @property
+    def error_msg(self):
+        return f"{self.msg} code={self.code} connId={self.connId}"
+
+    @property
+    def login_msg(self):
+        return f"login success connId={self.connId}"
+
+    @property
+    def subscribe_msg(self):
+        return f"subscribed to {self.arg.channel} connId={self.connId}"
+
 
 class OkxWsBboTbtData(msgspec.Struct):
     ts: str
@@ -160,7 +177,7 @@ class OkxWsTradeMsg(msgspec.Struct):
     data: list[OkxWsTradeData]
 
 
-class OkxWsFundingRateData(msgspec.Struct):
+class OkxWsFundingRateData(msgspec.Struct, kw_only=True):
     formulaType: str
     fundingRate: str
     fundingTime: str
@@ -174,7 +191,7 @@ class OkxWsFundingRateData(msgspec.Struct):
     nextFundingRate: str
     nextFundingTime: str
     premium: str
-    settFundingRate: str
+    settFundingRate: str | None = None
     settState: str
     ts: str
 
@@ -184,6 +201,18 @@ class OkxWsFundingRateMsg(msgspec.Struct):
     data: list[OkxWsFundingRateData]
 
 
+class OkxAlgoOrderData(msgspec.Struct):
+    attachAlgoClOrdId: str
+    tpOrdKind: str
+    tpTriggerPx: str
+    tpTriggerPxType: OkxTriggerType
+    tpOrdPx: str
+    slTriggerPx: str
+    slTriggerPxType: OkxTriggerType
+    slOrdPx: str
+    sz: str
+
+
 class OkxWsOrderData(msgspec.Struct):
     instType: OkxInstrumentType
     instId: str
@@ -222,11 +251,12 @@ class OkxWsOrderData(msgspec.Struct):
     lever: str  # leverage
     attachAlgoClOrdId: str  # attached algo order id
     tpTriggerPx: str  # take profit trigger price
-    tpTriggerPxType: str  # take profit trigger price type
+    tpTriggerPxType: OkxTriggerType  # take profit trigger price type
     tpOrdPx: str  # take profit order price
     slTriggerPx: str  # stop loss trigger price
-    slTriggerPxType: str  # stop loss trigger price type
+    slTriggerPxType: OkxTriggerType  # stop loss trigger price type
     slOrdPx: str  # stop loss order price
+    attachAlgoOrds: List[OkxAlgoOrderData]
     stpMode: str  # stop loss mode
     feeCcy: str  # fee currency
     fee: str  # fee
@@ -886,6 +916,21 @@ class OkxPositionResponse(msgspec.Struct):
     msg: str
 
 
+class OkxIndexCandlesticksResponse(msgspec.Struct):
+    code: str
+    data: list["OkxIndexCandlesticksResponseData"]
+    msg: str
+
+
+class OkxIndexCandlesticksResponseData(msgspec.Struct, array_like=True):
+    ts: int
+    o: str
+    h: str
+    l: str  # noqa: E741
+    c: str
+    confirm: str
+
+
 class OkxCandlesticksResponse(msgspec.Struct):
     code: str
     data: list["OkxCandlesticksResponseData"]
@@ -910,7 +955,7 @@ class OkxCandlesticksResponseData(msgspec.Struct, array_like=True):
     ts: int
     o: str
     h: str
-    l: str
+    l: str  # noqa: E741
     c: str
     vol: str
     volCcy: str
@@ -1077,3 +1122,276 @@ class OkxFinanceStakingDefiOffersInvestData(msgspec.Struct):
 class OkxFinanceStakingDefiOffersEarningData(msgspec.Struct):
     ccy: str
     earningType: str
+
+
+class OkxAccountConfigResponse(msgspec.Struct):
+    code: str
+    data: list["OkxAccountConfigResponseData"]
+    msg: str
+
+
+class OkxAccountConfigResponseData(msgspec.Struct):
+    """
+    Account configuration response data from OKX API.
+    """
+
+    uid: str  # Account ID of current request
+    mainUid: str  # Main Account ID of current request
+    acctLv: OkxAcctLv  # Account mode (1: Spot, 2: Futures, 3: Multi-currency margin, 4: Portfolio margin)
+    acctStpMode: str  # Account self-trade prevention mode (cancel_maker, cancel_taker, cancel_both)
+    posMode: OkxPositionMode  # Position mode (long_short_mode, net_mode)
+    autoLoan: bool  # Whether to borrow coins automatically
+    greeksType: (
+        str  # Current display type of Greeks (PA: coins, BS: Black-Scholes in dollars)
+    )
+    level: str  # User level of current real trading volume
+    levelTmp: str  # Temporary experience user level
+    ctIsoMode: str  # Contract isolated margin trading settings (automatic, autonomy)
+    mgnIsoMode: str  # Margin isolated margin trading settings (auto_transfers_ccy, automatic, quick_margin)
+    spotOffsetType: str  # Risk offset type (1: Spot-Derivatives(USDT), 2: Spot-Derivatives(Coin), 3: Only derivatives)
+    roleType: str  # Role type (0: General user, 1: Leading trader, 2: Copy trader)
+    traderInsts: list[str]  # Leading trade instruments
+    spotRoleType: str  # SPOT copy trading role type (0: General user, 1: Leading trader, 2: Copy trader)
+    spotTraderInsts: list[str]  # Spot lead trading instruments
+    opAuth: (
+        str  # Whether optional trading was activated (0: not activate, 1: activated)
+    )
+    kycLv: str  # Main account KYC level (0: No verification, 1: level 1, 2: level 2, 3: level 3)
+    label: str  # API key note
+    ip: str  # IP addresses linked with current API key
+    perm: str  # Permission of current API key (read_only, trade, withdraw)
+    liquidationGear: str  # Maintenance margin ratio level of liquidation alert
+    enableSpotBorrow: bool  # Whether borrow is allowed in Spot mode
+    spotBorrowAutoRepay: bool  # Whether auto-repay is allowed in Spot mode
+    type: str  # Account type (0: Main account, 1: Standard sub-account, 2: Managed trading sub-account, etc.)
+
+
+class OkxBatchOrderResponse(msgspec.Struct):
+    """
+    Response structure for batch order operations.
+    """
+
+    code: str  # Response code
+    msg: str  # Response message
+    data: list["OkxBatchOrderResponseData"]  # List of order data
+    inTime: str  # Time when the request was received by the REST gateway
+    outTime: str  # Time when the response was sent from the REST gateway
+
+
+class OkxBatchOrderResponseData(msgspec.Struct):
+    """
+    Data structure for individual order in batch order response.
+    """
+
+    ordId: str  # Order ID
+    clOrdId: str  # Client order ID
+    tag: str  # Tag associated with the order
+    ts: str  # Timestamp when the order was processed
+    sCode: str  # Status code of the order processing (0 means success)
+    sMsg: str  # Status message of the order processing (success or error message)
+
+
+################################################################################
+# Cancel Batch Orders: POST /api/v5/trade/cancel-batch-orders
+################################################################################
+
+
+class OkxCancelBatchOrderResponseData(msgspec.Struct):
+    """
+    Data structure for individual order in batch cancel order response.
+    """
+
+    ordId: str  # Order ID
+    clOrdId: str  # Client order ID
+    ts: str  # Timestamp when the order request processing is finished
+    sCode: str  # Event execution result code (0 means success)
+    sMsg: str  # Rejection message if the request is unsuccessful
+
+
+class OkxCancelBatchOrderResponse(msgspec.Struct):
+    """
+    Response structure for POST /api/v5/trade/cancel-batch-orders.
+    """
+
+    code: str  # Response code (0 means success)
+    msg: str  # Error message (empty if code is 0)
+    data: list[OkxCancelBatchOrderResponseData]  # Array of cancellation results
+    inTime: str  # Timestamp at REST gateway when request is received
+    outTime: str  # Timestamp at REST gateway when response is sent
+
+
+################################################################################
+# GET /api/v5/market/tickers
+################################################################################
+
+
+class OkxTickerData(msgspec.Struct):
+    """
+    Ticker data structure for OKX market tickers.
+    """
+
+    instType: str  # Instrument type
+    instId: str  # Instrument ID
+    last: str  # Last traded price
+    lastSz: str  # Last traded size
+    askPx: str  # Best ask price
+    askSz: str  # Best ask size
+    bidPx: str  # Best bid price
+    bidSz: str  # Best bid size
+    open24h: str  # Open price in the past 24 hours
+    high24h: str  # Highest price in the past 24 hours
+    low24h: str  # Lowest price in the past 24 hours
+    volCcy24h: str  # 24h trading volume in currency
+    vol24h: str  # 24h trading volume in contracts
+    sodUtc0: str  # Open price in UTC 0
+    sodUtc8: str  # Open price in UTC 8
+    ts: str  # Ticker data generation time
+
+
+class OkxTickersResponse(msgspec.Struct):
+    """
+    Response structure for GET /api/v5/market/tickers.
+    """
+
+    code: str  # Response code
+    msg: str  # Response message
+    data: list[OkxTickerData]  # List of ticker data
+
+
+################################################################################
+# GET /api/v5/trade/order
+################################################################################
+
+
+class OkxLinkedAlgoOrd(msgspec.Struct):
+    """Linked algorithm order details"""
+
+    algoId: str
+
+
+class OkxAttachAlgoOrd(msgspec.Struct):
+    """Attached TP/SL order details"""
+
+    attachAlgoId: str | None = None
+    attachAlgoClOrdId: str | None = None
+    tpOrdKind: str | None = None
+    tpTriggerPx: str | None = None
+    tpTriggerPxType: str | None = None
+    tpOrdPx: str | None = None
+    slTriggerPx: str | None = None
+    slTriggerPxType: str | None = None
+    slOrdPx: str | None = None
+    sz: str | None = None
+    amendPxOnTriggerType: str | None = None
+    failCode: str | None = None
+    failReason: str | None = None
+
+
+class OkxOrderData(msgspec.Struct):
+    """
+    Order data structure for GET /api/v5/trade/order response.
+    """
+
+    accFillSz: str  # Accumulated filled quantity
+    algoClOrdId: str  # Client-supplied Algo ID
+    algoId: str  # Algo ID
+    attachAlgoClOrdId: str  # Client-supplied Algo ID when placing order attaching TP/SL
+    attachAlgoOrds: list[
+        OkxAttachAlgoOrd
+    ]  # TP/SL information attached when placing order
+    avgPx: str  # Average filled price
+    cTime: str  # Creation time
+    cancelSource: str  # Code of the cancellation source
+    cancelSourceReason: str  # Reason for the cancellation
+    category: str  # Category (normal, twap, adl, etc.)
+    ccy: str  # Margin currency
+    clOrdId: str  # Client Order ID
+    fee: str  # Fee
+    feeCcy: str  # Fee currency
+    fillPx: str  # Last filled price
+    fillSz: str  # Last filled quantity
+    fillTime: str  # Last filled time
+    instId: str  # Instrument ID
+    instType: str  # Instrument type
+    isTpLimit: str  # Whether it is TP limit order
+    lever: str  # Leverage
+    linkedAlgoOrd: OkxLinkedAlgoOrd  # Linked SL order detail
+    ordId: str  # Order ID
+    ordType: OkxOrderType  # Order type
+    pnl: str  # Profit and loss
+    posSide: OkxPositionSide  # Position side
+    px: str  # Price
+    pxType: str  # Price type
+    pxUsd: str  # Options price in USD
+    pxVol: str  # Implied volatility of the options order
+    quickMgnType: str  # Quick Margin type
+    rebate: str  # Rebate amount
+    rebateCcy: str  # Rebate currency
+    reduceOnly: bool  # Whether the order can only reduce the position size
+    side: OkxOrderSide  # Order side
+    slOrdPx: str  # Stop-loss order price
+    slTriggerPx: str  # Stop-loss trigger price
+    slTriggerPxType: str  # Stop-loss trigger price type
+    source: str  # Order source
+    state: OkxOrderStatus  # State
+    stpId: str  # Self trade prevention ID
+    stpMode: str  # Self trade prevention mode
+    sz: str  # Quantity to buy or sell
+    tag: str  # Order tag
+    tdMode: str  # Trade mode
+    tgtCcy: str  # Order quantity unit setting for sz
+    tpOrdPx: str  # Take-profit order price
+    tpTriggerPx: str  # Take-profit trigger price
+    tpTriggerPxType: str  # Take-profit trigger price type
+    tradeId: str  # Last traded ID
+    tradeQuoteCcy: str  # The quote currency used for trading
+    uTime: str  # Update time
+
+
+class OkxOrderResponse(msgspec.Struct):
+    """
+    Response structure for GET /api/v5/trade/order.
+    """
+
+    code: str  # Response code
+    data: list[OkxOrderData]  # Order data
+    msg: str  # Response message
+
+
+class OkxWsApiOrderResponseData(msgspec.Struct, frozen=True, kw_only=True):
+    clOrdId: str
+    ordId: str
+    tag: str | None = None
+    ts: str
+    sCode: str
+    sMsg: str
+
+
+class OkxWsApiOrderResponse(msgspec.Struct, frozen=True):
+    """
+    WebSocket API order response structure.
+    """
+
+    field_id: str = msgspec.field(name="id")
+    op: OkxWsApiOp
+    data: list[OkxWsApiOrderResponseData]
+    code: str
+    msg: str
+    inTime: str
+    outTime: str
+
+    @property
+    def id(self):
+        return restore_uuid_hyphens(self.field_id)
+
+    @property
+    def is_success(self):
+        return self.code == "0"
+
+    @property
+    def error_msg(self):
+        return (
+            f"code={self.data[0].sCode}, msg={self.data[0].sMsg}"
+            if self.data
+            else "Unknown Error"
+        )
